@@ -32,4 +32,5 @@ def test_libvirt(request, host):
         print(cmd.stdout)
         print(cmd.stderr)
         assert 0 == cmd.rc
-        assert f"Size: {variables['libvirt_ram']} MB" in cmd.stdout
+        giga = int(variables['libvirt_ram'] / 1024)
+        assert f"Size: {giga} GB" in cmd.stdout
