@@ -2,7 +2,7 @@ from tests.modified_environ import modified_environ
 from enough.internal import cmd
 
 
-def test_enough_backup(capsys, mocker):
+def test_enough_backup(capsys, mocker, tmp_config_dir):
     # do not tamper with logging streams to avoid
     # ValueError: I/O operation on closed file.
     mocker.patch('cliff.app.App.configure_logging')
